@@ -13,10 +13,12 @@
 # limitations under the License.
 # ============================================================================
 
-from . import loader, utils
+from . import loader, converter, utils
 from .loader import *
+from .converter import *
 from .utils import *
 
 __all__ = []
 __all__.extend(loader.__all__)
+__all__.extend(converter.__all__)
 __all__.extend(utils.__all__)
