@@ -12,35 +12,41 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 # ============================================================================
-
 import numpy as np
-import tinyms as ts
 from PIL import Image
-from tinyms.primitives import Softmax
+import tinyms as ts
 
 from . import _transform_ops
 from ._transform_ops import *
 from .utils import ssd_bboxes_encode, ssd_bboxes_filter, jaccard_numpy
+from .. import Tensor
 from ..data import MnistDataset, Cifar10Dataset, ImageFolderDataset, VOCDataset, GeneratorDataset
+from ..primitives import Softmax
+from .transform_config import get_specified_config
 
 __all__ = [
     'mnist_transform', 'MnistTransform',
     'cifar10_transform', 'Cifar10Transform',
     'imagefolder_transform', 'ImageFolderTransform',
     'voc_transform', 'VOCTransform',
-    'cyclegan_transform', 'CycleGanDatasetTransform',
+    'shanshui_tranform', 'ShanshuiTransform',
+    'cyclegan_transform', 'CycleGanDatasetTransform'
 ]
 __all__.extend(_transform_ops.__all__)
 
 
-class DatasetTransform():
+class DatasetTransform(object):
     r'''
     Base class for all dataset transforms.
     '''
 
-    def __init__(self, labels=None):
-        self.labels = labels
-        self.transform_strategy = ['TOP1_CLASS', 'TOP5_CLASS']
+    def __init__(self, configs=None):
+        if configs:
+            self.configs = configs
+        else:
+            self.configs = get_specified_config('DatasetTransform')
+        self.labels = self.configs['labels']
+        self.transform_strategy = self.configs['transform_strategy']
 
     def apply_ds(self, ds, trans_func=None, repeat_size=1, batch_size=32,
                  num_parallel_workers=None):
@@ -77,20 +83,21 @@ class DatasetTransform():
             raise ValueError("Strategy should be one of {}, got {}.".format(self.transform_strategy, strategy))
 
         softmax = Softmax()
-        score_list = softmax(ts.array(input)).asnumpy()
+        score_list = softmax(Tensor(input, dtype=ts.float32)).asnumpy()
         if strategy == 'TOP1_CLASS':
             score = max(score_list[0])
-            return ('TOP1: ' + str(self.labels[input[0].argmax()]) + ', score: ' + str(format(score, '.20f')))
+            return ('TOP1: {}, score: {}').format(str(self.labels[input[0].argmax()]), str(round(score, 5)))
         else:
             label_index = np.argsort(input[0])[::-1]
             score_index = np.sort(score_list[0])[::-1]
             top5_labels = []
             res = ''
             top5_scores = score_index[:5].tolist()
-            for i in range(5):
+            top_num = int(strategy.split('_')[0].split('TOP')[-1])
+            for i in range(top_num):
                 top5_labels.append(self.labels[label_index[i]])
                 res += 'TOP' + str(i+1) + ": " + str(top5_labels[i]) + \
-                    ", score: " + str(format(top5_scores[i], '.20f')) + '\n'
+                       ", score: " + str(format(top5_scores[i], '.7f')) + '\t'
             return res
 
 
@@ -109,23 +116,30 @@ class MnistTransform(DatasetTransform):
         >>> from tinyms.vision import MnistTransform
         >>>
         >>> mnist_transform = MnistTransform()
-        >>> img = Image.open('example.jpg')
+        >>> img = Image.open('object_detection.jpg')
         >>> img = mnist_transform(img)
     '''
 
-    def __init__(self):
-        labels = [0, 1, 2, 3, 4, 5, 6, 7, 8, 9]
-        super().__init__(labels=labels)
+    def __init__(self, configs=None):
+        if configs:
+            self.configs = configs
+        else:
+            self.configs = get_specified_config('MnistTransform')
+        super().__init__(configs=self.configs)
+        self.labels = self.configs['labels']
+        self.transform_strategy = self.configs['transform_strategy']
         self.grayscale = Grayscale()
-        self.resize = Resize((32, 32))
-        self.normalize = Rescale(1 / 0.3081, -1 * 0.1307 / 0.3081)
-        self.rescale = Rescale(1.0 / 255.0, 0.0)
+        self.resize = Resize(self.configs['resize'])
+        self.normalize = Rescale(eval(self.configs['rescale1']['rescale_factor']),
+                                 eval(self.configs['rescale1']['shift_factor']))
+        self.rescale = Rescale(eval(self.configs['rescale2']['rescale_factor']),
+                               self.configs['rescale2']['shift_factor'])
 
     def __call__(self, img):
         if not isinstance(img, (np.ndarray, Image.Image)):
             raise TypeError("Input type should be numpy.ndarray or PIL.Image, got {}.".format(type(img)))
         if isinstance(img, np.ndarray):
-            img = Image.fromarray(img, mode='RGB')
+            img = Image.fromarray(img.astype('uint8')).convert('RGB')
         img = np.asarray(self.grayscale(img), dtype=np.float32)
         img = np.expand_dims(img, 2)
         img = self.resize(img)
@@ -180,20 +194,23 @@ class Cifar10Transform(DatasetTransform):
         >>> from tinyms.vision import Cifar10Transform
         >>>
         >>> cifar10_transform = Cifar10Transform()
-        >>> img = Image.open('example.jpg')
+        >>> img = Image.open('object_detection.jpg')
         >>> img = cifar10_transform(img)
     """
     '''
 
-    def __init__(self):
-        labels = ['airplane', 'automobile', 'bird', 'cat', 'deer',
-                  'dog', 'frog', 'horse', 'ship', 'truck']
-        super().__init__(labels=labels)
-        self.random_crop = RandomCrop((32, 32), (4, 4, 4, 4))
-        self.random_horizontal_flip = RandomHorizontalFlip(prob=0.5)
-        self.resize = Resize((224, 224))
-        self.rescale = Rescale(1.0 / 255.0, 0.0)
-        self.normalize = Normalize([0.4914, 0.4822, 0.4465], [0.2023, 0.1994, 0.2010])
+    def __init__(self, configs=None):
+        if configs:
+            self.configs = configs
+        else:
+            self.configs = get_specified_config('Cifar10Transform')
+        super().__init__(configs=self.configs)
+        self.random_crop = RandomCrop(self.configs['random_crop']['size'], self.configs['random_crop']['padding'])
+        self.random_horizontal_flip = RandomHorizontalFlip(prob=self.configs['random_horizontal_flip']['prob'])
+        self.resize = Resize(self.configs['resize'])
+        self.rescale = Rescale(eval(self.configs['rescale']['rescale_factor']),
+                               self.configs['rescale']['shift_factor'])
+        self.normalize = Normalize(self.configs['normalize']['mean'], self.configs['normalize']['std'])
 
     def __call__(self, img):
         if not isinstance(img, (np.ndarray, Image.Image)):
@@ -245,7 +262,7 @@ class ImageFolderTransform(DatasetTransform):
     ImageFolder dataset transform class.
 
     Inputs:
-        img(Union[numpy.ndarray, PIL.Image]): Image to be transformed in ImageFolder-style.
+        img (Union[numpy.ndarray, PIL.Image]): Image to be transformed in ImageFolder-style.
 
     Outputs:
         numpy.ndarray, transformed image.
@@ -255,28 +272,24 @@ class ImageFolderTransform(DatasetTransform):
         >>> from tinyms.vision import ImageFolderTransform
         >>>
         >>> imagefolder_transform = ImageFolderTransform()
-        >>> img = Image.open('example.jpg')
+        >>> img = Image.open('object_detection.jpg')
         >>> img = imagefolder_transform(img)
     '''
 
-    def __init__(self):
-        labels = ["Agaricus双孢蘑菇,伞菌目,蘑菇科,蘑菇属,广泛分布于北半球温带,无毒",
-                  "Amanita毒蝇伞,伞菌目,鹅膏菌科,鹅膏菌属,主要分布于我国黑龙江、吉林、四川、西藏、云南等地,有毒",
-                  "Boletus丽柄牛肝菌,伞菌目,牛肝菌科,牛肝菌属,分布于云南、陕西、甘肃、西藏等地,有毒",
-                  "Cortinarius掷丝膜菌,伞菌目,丝膜菌科,丝膜菌属,分布于湖南等地(夏秋季在山毛等阔叶林地上生长)",
-                  "Entoloma霍氏粉褶菌,伞菌目,粉褶菌科,粉褶菌属,主要分布于新西兰北岛和南岛西部,有毒",
-                  "Hygrocybe浅黄褐湿伞,伞菌目,蜡伞科,湿伞属,分布于香港(见于松仔园),有毒",
-                  "Lactarius松乳菇,红菇目,红菇科,乳菇属,广泛分布于亚热带松林地,无毒",
-                  "Russula褪色红菇,伞菌目,红菇科,红菇属,分布于河北、吉林、四川、江苏、西藏等地,无毒",
-                  "Suillus乳牛肝菌,牛肝菌目,乳牛肝菌科,乳牛肝菌属,分布于吉林、辽宁、山西、安徽、江西、浙江、湖南、四川、贵州等地,无毒",
-                  ]
-        super().__init__(labels=labels)
-        self.random_crop_decode_resize = RandomCropDecodeResize((224, 224), scale=(0.08, 1.0), ratio=(0.75, 1.333))
-        self.random_horizontal_flip = RandomHorizontalFlip(prob=0.5)
-        self.resize = Resize((256, 256))
-        self.center_crop = CenterCrop((224, 224))
-        self.normalize = Normalize([0.485 * 255, 0.456 * 255, 0.406 * 255],
-                                   [0.229 * 255, 0.224 * 255, 0.225 * 255])
+    def __init__(self, configs=None):
+        if configs:
+            self.configs = configs
+        else:
+            self.configs = get_specified_config('ImageFolderTransform')
+        super().__init__(configs=self.configs)
+        self.random_crop_decode_resize = RandomCropDecodeResize(
+            self.configs['random_crop_decode_resize']['size'],
+            scale=tuple(self.configs['random_crop_decode_resize']['scale']),
+            ratio=tuple(self.configs['random_crop_decode_resize']['ratio']))
+        self.random_horizontal_flip = RandomHorizontalFlip(prob=self.configs['random_horizontal_flip']['prob'])
+        self.resize = Resize(self.configs['resize'])
+        self.center_crop = CenterCrop(self.configs['center_crop'])
+        self.normalize = Normalize(self.configs['normalize']['mean'], self.configs['normalize']['std'])
 
     def _center_crop(self, img):
         y, x, _ = img.shape
@@ -340,7 +353,7 @@ class VOCTransform(DatasetTransform):
     VOC dataset transform class.
 
     Inputs:
-        img(Union[numpy.ndarray, PIL.Image]): Image to be transformed in VOC-style.
+        img (Union[numpy.ndarray, PIL.Image]): Image to be transformed in VOC-style.
 
     Outputs:
         numpy.ndarray, transformed image.
@@ -350,22 +363,22 @@ class VOCTransform(DatasetTransform):
         >>> from tinyms.vision import VOCTransform
         >>>
         >>> voc_transform = VOCTransform()
-        >>> img = Image.open('example.jpg')
+        >>> img = Image.open('object_detection.jpg')
         >>> img = voc_transform(img)
     '''
 
-    def __init__(self):
-        labels = ['background',
-                  'aeroplane', 'bicycle', 'bird', 'boat', 'bottle',
-                  'bus', 'car', 'cat', 'chair', 'cow',
-                  'diningtable', 'dog', 'horse', 'motorbike', 'person',
-                  'pottedplant', 'sheep', 'sofa', 'train', 'tvmonitor']
-        super().__init__(labels=labels)
-        self.resize = Resize((300, 300))
-        self.horizontal_flip = PILRandomHorizontalFlip(1.0)
-        self.normalize = Normalize(mean=[0.485 * 255, 0.456 * 255, 0.406 * 255],
-                                   std=[0.229 * 255, 0.224 * 255, 0.225 * 255])
-        self.random_color_adjust = RandomColorAdjust(brightness=0.4, contrast=0.4, saturation=0.4)
+    def __init__(self, configs=None):
+        if configs:
+            self.configs = configs
+        else:
+            self.configs = get_specified_config('VOCTransform')
+        super().__init__(configs=self.configs)
+        self.resize = Resize(self.configs['resize'])
+        self.horizontal_flip = PILRandomHorizontalFlip(self.configs['horizontal_flip'])
+        self.normalize = Normalize(self.configs['normalize']['mean'], self.configs['normalize']['std'])
+        self.random_color_adjust = RandomColorAdjust(brightness=self.configs['random_color_adjust']['brightness'],
+                                                     contrast=self.configs['random_color_adjust']['contrast'],
+                                                     saturation=self.configs['random_color_adjust']['saturation'])
 
     def _preprocess_fn(self, image, boxes, labels, is_training=True):
         """Preprocess function for voc dataset."""
@@ -458,7 +471,7 @@ class VOCTransform(DatasetTransform):
         Apply preprocess operation on VOCDataset instance.
 
         Args:
-            cifar10_ds (data.VOCDataset): VOCDataset instance.
+            voc_ds (data.VOCDataset): VOCDataset instance.
             repeat_size (int): The repeat size of dataset. Default: 1.
             batch_size (int): Batch size. Default: 32.
             num_parallel_workers (int): The number of concurrent workers. Default: None.
@@ -525,12 +538,47 @@ class VOCTransform(DatasetTransform):
         return pred_res
 
 
+class ShanshuiTransform(VOCTransform):
+    r'''
+    Shanshui dataset transform class.
+
+    Inputs:
+        img (Union[numpy.ndarray, PIL.Image]): Image to be transformed in VOC-style.
+
+    Outputs:
+        numpy.ndarray, transformed image.
+
+    Examples:
+        >>> from PIL import Image
+        >>> from tinyms.vision import ShanshuiTransform
+        >>>
+        >>> shanshui_transform = ShanshuiTransform()
+        >>> img = Image.open('object_detection.jpg')
+        >>> img = shanshui_transform(img)
+    '''
+
+    def __init__(self, configs=None):
+        if configs:
+            self.configs = configs
+        else:
+            self.configs = get_specified_config('ShanshuiTransform')
+        super().__init__(configs=self.configs)
+
+    def __call__(self, img):
+        if not isinstance(img, (np.ndarray, Image.Image)):
+            raise TypeError("Input type should be numpy.ndarray or PIL.Image, got {}.".format(type(img)))
+        img = self.resize(img)
+        img = self.normalize(img)
+        img = hwc2chw(img)
+        return img
+
+
 class CycleGanDatasetTransform():
     r'''
     CycleGan dataset transform class.
 
     Inputs:
-        img(Union[numpy.ndarray, PIL.Image]): Image to be transformed in city_scape.
+        img (Union[numpy.ndarray, PIL.Image]): Image to be transformed in city_scape.
 
     Outputs:
         numpy.ndarray, transformed image.
@@ -540,15 +588,21 @@ class CycleGanDatasetTransform():
         >>> from tinyms.vision import CycleGanDatasetTransform
         >>>
         >>> cyclegan_transform = CycleGanDatasetTransform()
-        >>> img = Image.open('example.jpg')
+        >>> img = Image.open('object_detection.jpg')
         >>> img = cyclegan_transform(img)
     '''
 
-    def __init__(self):
-        self.random_resized_crop = RandomResizedCrop(256, scale=(0.5, 1.0), ratio=(0.75, 1.333))
-        self.random_horizontal_flip = RandomHorizontalFlip(prob=0.5)
-        self.resize = Resize((256, 256))
-        self.normalize = Normalize(mean=[0.5 * 255] * 3, std=[0.5 * 255] * 3)
+    def __init__(self, configs=None):
+        if configs:
+            self.configs = configs
+        else:
+            self.configs = get_specified_config('CycleGanDatasetTransform')
+        self.random_resized_crop = RandomResizedCrop(self.configs['random_resized_crop']['size'],
+                                                     scale=tuple(self.configs['random_resized_crop']['scale']),
+                                                     ratio=tuple(self.configs['random_resized_crop']['ratio']))
+        self.random_horizontal_flip = RandomHorizontalFlip(prob=self.configs['random_horizontal_flip']['prob'])
+        self.resize = Resize(self.configs['resize'])
+        self.normalize = Normalize(mean=self.configs['normalize']['mean'], std=self.configs['normalize']['std'])
 
     def __call__(self, img):
         if not isinstance(img, (np.ndarray, Image.Image)):
@@ -615,4 +669,5 @@ mnist_transform = MnistTransform()
 cifar10_transform = Cifar10Transform()
 imagefolder_transform = ImageFolderTransform()
 voc_transform = VOCTransform()
-cyclegan_transform = CycleGanDatasetTransform()
+shanshui_tranform = ShanshuiTransform()
+cyclegan_transform = CycleGanDatasetTransform()
\ No newline at end of file
